==> Ver%203.0.0.zip: Ver 3.0.0/src/jp/mosp/workflow/action/ApprovalUnitListAction.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2008 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.workflow.action;

import java.io.Serializable;
import java.util.Comparator;

import jp.mosp.common.action.MosPWorkflowAction;
import jp.mosp.common.common.MospConst;
import jp.mosp.common.common.MospException;
import jp.mosp.common.common.MospUtility;

import jp.mosp.workflow.dto.AmUnitDto;
import jp.mosp.workflow.vo.ApprovalUnitListVo;

public class ApprovalUnitListAction extends MosPWorkflowAction {

	// R}h
	private static final String CMD_UNIT_LIST_SHOW      = "S2810";
	private static final String CMD_UNIT_LIST_SEARCH    = "S2811";
	private static final String CMD_UNIT_LIST_RE_SEARCH = "S2812";
	private static final String CMD_UNIT_LIST_SORT      = "S2813";

	/**
	 * RXgN^
	 */
	public ApprovalUnitListAction() {
		super();
	}

	/**
	 * ANV
	 */
	public void action() throws Exception {
		// DBRlNV擾
		getConnection();
		// SYSTEMmF
		confirmSystemAuth();
		// VO̎擾
		ApprovalUnitListVo vo;
		Object obj = session.getAttribute(MospConst.ATT_FORMER_VO);
		if (obj instanceof ApprovalUnitListVo) {
			vo = (ApprovalUnitListVo)obj;
			vo.clearMessage();
			vo.clearErrField();
		} else {
			vo = new ApprovalUnitListVo();
		}
		vo.clearMessage();
		vo.clearErrField();
		vo.initVo(cfg, msg, cmd, aspUser, user);
		// VOyуtH[hURL̐ݒ
		setVo(vo);
		setUrl(vo.getRetUrl());
		session.setAttribute(MospConst.ATT_FORMER_VO, vo);
		// l{擾
		vo.aryPltUser = getBasisArrayAll();
		// R}h̏
		if (cmd.equals(CMD_UNIT_LIST_SHOW)) {
			// lɃZbg
			vo.setSearchmode(ApprovalUnitListVo.SEARCH_OFF);
		} else if (cmd.equals(CMD_UNIT_LIST_SEARCH)) {
			// 
			vo.setParams(request);
			searchUnitList(vo);
			vo.setFormerKey(vo.KEY_UNIT_CODE);
			vo.setIsAscending(true);
			vo.initListInfo();
		} else if (cmd.equals(CMD_UNIT_LIST_RE_SEARCH)) {
			// Č
			if (vo.getSearchmode() == ApprovalUnitListVo.SEARCH_ON) {
				session.removeAttribute(MospConst.ATT_DTO);
				searchUnitList(vo);
				vo.setPageButton();
				sortList(vo);
			}
		} else if (cmd.equals(CMD_UNIT_LIST_SORT)) {
			// \[g
			sortList(key1, vo);
		} else {
			throw new MospException(MospConst.EX_CMD_INVALID);
		}
	}

	/**
	 * jbgXg
	 * @param vo UserListVoCX^X
	 * @throws Exception
	 */
	private void searchUnitList(ApprovalUnitListVo vo) throws Exception {
		// DBRlNV̎擾
		if (conn == null) {
			getConnection();
		}
		// 
		prepareAmUnitDao();
		vo.setFields(unitDao.findForCondition(
				vo.getTxtUnitCode(), vo.getTxtKCode(), vo.getTxtKName())
		);
		// Ώۂꍇ̃bZ[Wݒ
		if (vo.getEscAryUnit().length == 0) {
			vo.addErrMessage(MospUtility.getMessage(msg, MospConst.MSG_NO_DATA, ""));
		}
		// [hݒ
		vo.setSearchmode(ApprovalUnitListVo.SEARCH_ON);			
	}

	/**
	 * \[g
	 * @param key \[gL[
	 * @param vo \[gΏList܂VO
	 * @throws MospException
	 */
	private void sortList(String key, ApprovalUnitListVo vo) throws MospException {
		vo.sortList(key, getComparator(key, vo));
		vo.setFields(vo.getList());
	}

	/**
	 * \[g(VÕL[Ń\[g)
	 * @param vo \[gΏList܂VO
	 * @throws MospException
	 */
	private void sortList(ApprovalUnitListVo vo) throws MospException {
		vo.sortList(getComparator(vo.getFormerKey(), vo));
		vo.setFields(vo.getList());
	}

	/**
	 * rNX擾
	 * @param key \[gL[
	 * @param vo \[gΏList܂VO
	 * @throws MospException
	 */
	private Comparator getComparator(String key, ApprovalUnitListVo vo) throws MospException {
		Comparator comp = null;
		if (key.equals(vo.KEY_UNIT_CODE)) {
			comp = new CompUnitCode();
		} else if (key.equals(vo.KEY_MAIN)) {
			comp = new CompMain();
		} else if (key.equals(vo.KEY_AGENT)) {
			comp = new CompAgent();
		} else if (key.equals(vo.KEY_START_DATE)) {
			comp = new CompStartDate();
		} else {
			throw new MospException(MospConst.EX_SORTKEY_INVALID);
		}
		return comp;
	}

	/**
	 * jbgR[hɂrNX
	 */
	protected static class CompUnitCode implements Comparator, Serializable {
		private static final long serialVersionUID = 8882101817659803340L;
		public int compare(Object obj1, Object obj2) {
			AmUnitDto dto1 = (AmUnitDto)obj1;
			AmUnitDto dto2 = (AmUnitDto)obj2;
			return dto1.getUnitCode().compareTo(dto2.getUnitCode());
		}
	}

	/**
	 * F҂ɂrNX
	 */
	protected static class CompMain implements Comparator, Serializable {
		private static final long serialVersionUID = -1958254792298208211L;
		public int compare(Object obj1, Object obj2) {
			AmUnitDto dto1 = (AmUnitDto)obj1;
			AmUnitDto dto2 = (AmUnitDto)obj2;
			return dto1.getMain().compareTo(dto2.getMain());
		}
	}

	/**
	 * 㗝ɂrNX
	 */
	protected static class CompAgent implements Comparator, Serializable {
		private static final long serialVersionUID = 1656557705586257941L;
		public int compare(Object obj1, Object obj2) {
			AmUnitDto dto1 = (AmUnitDto)obj1;
			AmUnitDto dto2 = (AmUnitDto)obj2;
			return dto1.getAgent().compareTo(dto2.getAgent());
		}
	}

	/**
	 * JnɂrNX
	 */
	protected static class CompStartDate implements Comparator, Serializable {
		private static final long serialVersionUID = 3154045096780718675L;
		public int compare(Object obj1, Object obj2) {
			AmUnitDto dto1 = (AmUnitDto)obj1;
			AmUnitDto dto2 = (AmUnitDto)obj2;
			return dto1.getStartDate().compareTo(dto2.getStartDate());
		}
	}

}

==> Ver%203.1.1.zip: Ver 3.1.1/src/jp/mosp/workflow/action/ApprovalUnitListAction.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.workflow.action;

import java.io.Serializable;
import java.util.Comparator;

import jp.mosp.common.action.MosPWorkflowAction;
import jp.mosp.common.common.MospConst;
import jp.mosp.common.common.MospException;
import jp.mosp.common.common.MospUtility;

import jp.mosp.workflow.dto.AmUnitDto;
import jp.mosp.workflow.vo.ApprovalUnitListVo;

public class ApprovalUnitListAction extends MosPWorkflowAction {

	// R}h
	private static final String CMD_UNIT_LIST_SHOW      = "S2810";
	private static final String CMD_UNIT_LIST_SEARCH    = "S2811";
	private static final String CMD_UNIT_LIST_RE_SEARCH = "S2812";
	private static final String CMD_UNIT_LIST_SORT      = "S2813";

	/**
	 * RXgN^
	 */
	public ApprovalUnitListAction() {
		super();
	}

	/**
	 * ANV
	 */
	public void action() throws Exception {
		// DBRlNV擾
		getConnection();
		// SYSTEMmF
		confirmSystemAuth();
		// VO̎擾
		ApprovalUnitListVo vo;
		Object obj = session.getAttribute(MospConst.ATT_FORMER_VO);
		if (obj instanceof ApprovalUnitListVo) {
			vo = (ApprovalUnitListVo)obj;
		} else {
			vo = new ApprovalUnitListVo();
		}
		vo.clearMessage();
		vo.clearErrField();
		vo.initVo(cfg, msg, cmd, aspUser, user);
		// VOyуtH[hURL̐ݒ
		setVo(vo);
		setUrl(vo.getRetUrl());
		session.setAttribute(MospConst.ATT_FORMER_VO, vo);
		// l{擾
		vo.aryPltUser = getBasisArrayAll();
		// R}h̏
		if (cmd.equals(CMD_UNIT_LIST_SHOW)) {
			// lɃZbg
			vo.setSearchmode(ApprovalUnitListVo.SEARCH_OFF);
		} else if (cmd.equals(CMD_UNIT_LIST_SEARCH)) {
			// 
			vo.setParams(request);
			searchUnitList(vo);
			vo.setFormerKey(vo.KEY_UNIT_CODE);
			vo.setIsAscending(true);
			vo.initListInfo();
		} else if (cmd.equals(CMD_UNIT_LIST_RE_SEARCH)) {
			// Č
			if (vo.getSearchmode() == ApprovalUnitListVo.SEARCH_ON) {
				session.removeAttribute(MospConst.ATT_DTO);
				searchUnitList(vo);
				vo.setPageButton();
				sortList(vo);
			}
		} else if (cmd.equals(CMD_UNIT_LIST_SORT)) {
			// \[g
			sortList(key1, vo);
		} else {
			throw new MospException(MospConst.EX_CMD_INVALID);
		}
	}

	/**
	 * jbgXg
	 * @param vo UserListVoCX^X
	 * @throws Exception
	 */
	private void searchUnitList(ApprovalUnitListVo vo) throws Exception {
		// DBRlNV̎擾
		if (conn == null) {
			getConnection();
		}
		// 
		vo.setFields(unitDao().findForCondition(
				vo.getTxtUnitCode(), vo.getTxtKCode(), vo.getTxtKName())
		);
		// Ώۂꍇ̃bZ[Wݒ
		if (vo.getEscAryUnit().length == 0) {
			vo.addErrMessage(MospUtility.getMessage(msg, MospConst.MSG_NO_DATA, ""));
		}
		// [hݒ
		vo.setSearchmode(ApprovalUnitListVo.SEARCH_ON);
	}

	/**
	 * \[g
	 * @param key \[gL[
	 * @param vo \[gΏList܂VO
	 * @throws MospException
	 */
	private void sortList(String key, ApprovalUnitListVo vo) throws MospException {
		vo.sortList(key, getComparator(key, vo));
		vo.setFields(vo.getList());
	}

	/**
	 * \[g(VÕL[Ń\[g)
	 * @param vo \[gΏList܂VO
	 * @throws MospException
	 */
	private void sortList(ApprovalUnitListVo vo) throws MospException {
		vo.sortList(getComparator(vo.getFormerKey(), vo));
		vo.setFields(vo.getList());
	}

	/**
	 * rNX擾
	 * @param key \[gL[
	 * @param vo \[gΏList܂VO
	 * @throws MospException
	 */
	private Comparator<Object> getComparator(String key, ApprovalUnitListVo vo) throws MospException {
		Comparator<Object> comp = null;
		if (key.equals(vo.KEY_UNIT_CODE)) {
			comp = new CompUnitCode();
		} else if (key.equals(vo.KEY_MAIN)) {
			comp = new CompMain();
		} else if (key.equals(vo.KEY_AGENT)) {
			comp = new CompAgent();
		} else if (key.equals(vo.KEY_START_DATE)) {
			comp = new CompStartDate();
		} else {
			throw new MospException(MospConst.EX_SORTKEY_INVALID);
		}
		return comp;
	}

	/**
	 * jbgR[hɂrNX
	 */
	protected static class CompUnitCode implements Comparator<Object>, Serializable {
		private static final long serialVersionUID = 8882101817659803340L;
		public int compare(Object obj1, Object obj2) {
			AmUnitDto dto1 = (AmUnitDto)obj1;
			AmUnitDto dto2 = (AmUnitDto)obj2;
			return dto1.getUnitCode().compareTo(dto2.getUnitCode());
		}
	}

	/**
	 * F҂ɂrNX
	 */
	protected static class CompMain implements Comparator<Object>, Serializable {
		private static final long serialVersionUID = -1958254792298208211L;
		public int compare(Object obj1, Object obj2) {
			AmUnitDto dto1 = (AmUnitDto)obj1;
			AmUnitDto dto2 = (AmUnitDto)obj2;
			return dto1.getMain().compareTo(dto2.getMain());
		}
	}

	/**
	 * 㗝ɂrNX
	 */
	protected static class CompAgent implements Comparator<Object>, Serializable {
		private static final long serialVersionUID = 1656557705586257941L;
		public int compare(Object obj1, Object obj2) {
			AmUnitDto dto1 = (AmUnitDto)obj1;
			AmUnitDto dto2 = (AmUnitDto)obj2;
			return dto1.getAgent().compareTo(dto2.getAgent());
		}
	}

	/**
	 * JnɂrNX
	 */
	protected static class CompStartDate implements Comparator<Object>, Serializable {
		private static final long serialVersionUID = 3154045096780718675L;
		public int compare(Object obj1, Object obj2) {
			AmUnitDto dto1 = (AmUnitDto)obj1;
			AmUnitDto dto2 = (AmUnitDto)obj2;
			return dto1.getStartDate().compareTo(dto2.getStartDate());
		}
	}

}
